Crate dsntk_recognizer

Crate dsntk_recognizer 

Decision table recognizer

Overview

Decision table recognizer used by dsntk crate.

Recognizes decision tables defined as Unicode or Markdown text. To be properly recognized, the structure of the decision table must be conformant to DMN™ standard.

Example of decision table defined using Unicode characters:

  ┌───┬────────────┬───────╥──────────┐
  │ U │  Customer  │ Order ║ Discount │
  ╞═══╪════════════╪═══════╬══════════╡
  │ 1 │ "Business" │  <10  ║   0.10   │
  ├───┼────────────┼───────╫──────────┤
  │ 2 │ "Business" │ >=10  ║   0.15   │
  ├───┼────────────┼───────╫──────────┤
  │ 3 │ "Private"  │   -   ║   0.05   │
  └───┴────────────┴───────╨──────────┘

Example of decision table defined using Markdown:

UCustomerOrderDiscount
iio
1“Business”<100.10
2“Business”>=100.15
3“Private”-0.05

Structs

AnnotationClause
Represents a rule annotation clause.
AnnotationEntry
Represents a rule annotation entry.
DecisionRule
Represents a decision rule.
DecisionTable
Represents a decision table.
InputClause
Represents an input clause.
InputEntry
Represents an input entry.
OutputClause
Represents an output clause.
OutputEntry
Represents an output entry.

Enums

BuiltinAggregator
Enumeration of built-in aggregators for HitPolicy.
DecisionTableOrientation
Enumeration of preferred decision table orientations.
HitPolicy
Enumeration of hit policies.

Functions

from_markdown
Recognizes a decision table defined as Markdown text.
from_unicode
Recognizes a decision table defined as Unicode text.