DecisionRule

Struct DecisionRule 

pub struct DecisionRule {
    pub input_entries: Vec<InputEntry>,
    pub output_entries: Vec<OutputEntry>,
    pub annotation_entries: Vec<AnnotationEntry>,
}
Represents a decision rule.

Fields

input_entries: Vec<InputEntry>

Ordered list of input entries that compose decision rule.

output_entries: Vec<OutputEntry>

Ordered list of output entries that compose decision rule.

annotation_entries: Vec<AnnotationEntry>

Ordered list of rule annotations that compose decision rule.