Decision table recognizer
Overview
Decision table recognizer used by dsntk crate.
Recognizes decision tables defined as Unicode or Markdown text. To be properly recognized, the structure of the decision table must be conformant to DMN™ standard.
Example of decision table defined using Unicode characters:
┌───┬────────────┬───────╥──────────┐
│ U │ Customer │ Order ║ Discount │
╞═══╪════════════╪═══════╬══════════╡
│ 1 │ "Business" │ <10 ║ 0.10 │
├───┼────────────┼───────╫──────────┤
│ 2 │ "Business" │ >=10 ║ 0.15 │
├───┼────────────┼───────╫──────────┤
│ 3 │ "Private" │ - ║ 0.05 │
└───┴────────────┴───────╨──────────┘Example of decision table defined using Markdown:
| U | Customer | Order | Discount |
|---|---|---|---|
i | i | o | |
| 1 | “Business” | <10 | 0.10 |
| 2 | “Business” | >=10 | 0.15 |
| 3 | “Private” | - | 0.05 |
Structs
- Annotation
Clause - Represents a rule annotation clause.
- Annotation
Entry - Represents a rule annotation entry.
- Decision
Rule - Represents a decision rule.
- Decision
Table - Represents a decision table.
- Input
Clause - Represents an input clause.
- Input
Entry - Represents an input entry.
- Output
Clause - Represents an output clause.
- Output
Entry - Represents an output entry.
Enums
- Builtin
Aggregator - Enumeration of built-in aggregators for HitPolicy.
- Decision
Table Orientation - Enumeration of preferred decision table orientations.
- HitPolicy
- Enumeration of hit policies.
Functions
- from_
markdown - Recognizes a decision table defined as Markdown text.
- from_
unicode - Recognizes a decision table defined as Unicode text.